==> clevertap-android-sdk-2.2.0-sources.jar: com/clevertap/android/sdk/DataHandler.java <==
/*
 * Author: Jude Pereira
 * Copyright (c) 2014
 */

package com.clevertap.android.sdk;

import android.content.Context;
import org.json.JSONException;
import org.json.JSONObject;

/**
 * Provides various methods to send arbitrary data to CleverTap.
 */
public final class DataHandler {

    private final Context context;

    DataHandler(Context context) {
        this.context = context;
    }

    /**
     * internal only so our unregister on change user doesn't set the GcmManager flag that
     * the public api exposes
     *
     */
    void handleGCMRegistration(String gcmId, boolean register) {
        JSONObject event = new JSONObject();
        JSONObject gcmDetails = new JSONObject();
        try {
            gcmDetails.put("action", register ? "register" : "unregister");
            gcmDetails.put("id", gcmId);
            gcmDetails.put("type", "gcm");
            event.put("data", gcmDetails);
            QueueManager.queueEvent(context, event, Constants.DATA_EVENT);
        } catch (JSONException e) {
            // we won't get here
        }
    }

    /**
     * Sends the GCM registration ID to CleverTap.
     *
     * @param gcmId    The GCM registration ID
     * @param register Boolean indicating whether to register
     *                 or not for receiving push messages from CleverTap.
     *                 Set this to true to receive push messages from CleverTap,
     *                 and false to not receive any messages from CleverTap.
     */
    public void pushGcmRegistrationId(String gcmId, boolean register) {
        handleGCMRegistration(gcmId, register);
        try {
            GcmManager.enableGcmPushNotifications(context, register);
        } catch (Throwable t) {
            // we won't get here
        }
    }
}

==> clevertap-android-sdk-3.1.0-sources.jar: com/clevertap/android/sdk/DataHandler.java <==
/*
 * Author: Jude Pereira
 * Copyright (c) 2014
 */

package com.clevertap.android.sdk;

import android.content.Context;
import org.json.JSONException;
import org.json.JSONObject;

/**
 * Provides various methods to send arbitrary data to CleverTap.
 */
public final class DataHandler {

    private final Context context;

    DataHandler(Context context) {
        this.context = context;
    }

    /**
     * For internal use, don't call the public API internally
     *
     */
    static void pushDeviceToken(final Context context, final String token, final boolean register, final PushType type) {
        if (token == null || type == null ) return;

        JSONObject event = new JSONObject();
        JSONObject data = new JSONObject();
        try {
            String action = register ? "register" : "unregister";
            data.put("action", action);
            data.put("id", token);
            data.put("type", type.toString());
            event.put("data", data);
            Logger.logFine("DataHandler: pushing device token with action " + action + " and type " + type.toString());
            QueueManager.queueEvent(context, event, Constants.DATA_EVENT);
        } catch (JSONException e) {
            // we won't get here
        }
    }

    /**
     * Sends the GCM registration ID to CleverTap.
     *
     * @param gcmId    The GCM registration ID
     * @param register Boolean indicating whether to register
     *                 or not for receiving push messages from CleverTap.
     *                 Set this to true to receive push messages from CleverTap,
     *                 and false to not receive any messages from CleverTap.
     */
    public void pushGcmRegistrationId(String gcmId, boolean register) {
        pushDeviceToken(context, gcmId, register, PushType.GCM);
    }

    /**
     * Sends the FCM registration ID to CleverTap.
     *
     * @param fcmId    The FCM registration ID
     * @param register Boolean indicating whether to register
     *                 or not for receiving push messages from CleverTap.
     *                 Set this to true to receive push messages from CleverTap,
     *                 and false to not receive any messages from CleverTap.
     */
    public void pushFcmRegistrationId(String fcmId, boolean register) {
        pushDeviceToken(context, fcmId, register, PushType.FCM);
    }
}
